@@ -1,6 +1,6 @@
 // This file is part of BOINC.
 // http://boinc.berkeley.edu
-// Copyright (C) 2019 University of California
+// Copyright (C) 2022 University of California
 //
 // BOINC is free software; you can redistribute it and/or modify it
 // under the terms of the GNU Lesser General Public License
@@ -72,7 +72,7 @@ void GUI_URL::print() {
 
 void PROJECT::print_disk_usage() {
     printf("   master URL: %s\n", master_url);
-    printf("   disk usage: %.2fMB\n", disk_usage/MEGA);
+    printf("   disk usage: %.2fGB\n", disk_usage/GIGA);
 }
 
 void PROJECT::print() {
@@ -96,7 +96,7 @@ void PROJECT::print() {
     printf("   ended: %s\n", ended?"yes":"no");
     printf("   suspended via GUI: %s\n", suspended_via_gui?"yes":"no");
     printf("   don't request more work: %s\n", dont_request_more_work?"yes":"no");
-    printf("   disk usage: %.2fMB\n", disk_usage/MEGA);
+    printf("   disk usage: %.2fGB\n", disk_usage/GIGA);
     time_t foo = (time_t)last_rpc_time;
     printf("   last RPC: %s\n", ctime(&foo));
     printf("   project files downloaded: %f\n", project_files_downloaded_time);
@@ -134,6 +134,7 @@ void APP_VERSION::print() {
 }
 
 void WORKUNIT::print() {
+    printf("   project: %s\n", project->project_name.c_str());
     printf("   name: %s\n", name);
     printf("   FP estimate: %e\n", rsc_fpops_est);
     printf("   FP bound: %e\n", rsc_fpops_bound);
@@ -151,7 +152,11 @@ void WORKUNIT::print() {
 void RESULT::print() {
     printf("   name: %s\n", name);
     printf("   WU name: %s\n", wu_name);
-    printf("   project URL: %s\n", project_url);
+    if (project) {
+        printf("   project: %s\n", project->project_name.c_str());
+    } else {
+        printf("   project URL: %s\n", project_url);
+    }
     time_t foo = (time_t)received_time;
     printf("   received: %s", ctime(&foo));
     foo = (time_t)report_deadline;
@@ -207,6 +212,7 @@ void FILE_TRANSFER::print() {
     printf("   sticky: %s\n", sticky?"yes":"no");
     printf("   xfer active: %s\n", xfer_active?"yes":"no");
     printf("   time_so_far: %f\n", time_so_far);
+    if (xfer_active) printf("   estimated_xfer_time_remaining: %f\n", estimated_xfer_time_remaining);
     printf("   bytes_xferred: %f\n", bytes_xferred);
     printf("   xfer_speed: %f\n", xfer_speed);
 }
@@ -218,15 +224,15 @@ void MESSAGE::print() {
 }
 
 void GR_PROXY_INFO::print() {
-    printf("HTTP server name: %s\n",this->http_server_name.c_str()); 
-    printf("HTTP server port: %d\n",this->http_server_port); 
-    printf("HTTP user name: %s\n",this->http_user_name.c_str()); 
-    //printf("HTTP user password: %s\n",this->http_user_passwd.c_str()); 
-    printf("SOCKS server name: %s\n",this->socks_server_name.c_str()); 
-    printf("SOCKS server port: %d\n",this->socks_server_port); 
-    printf("SOCKS5 user name: %s\n",this->socks5_user_name.c_str()); 
-    //printf("SOCKS5 user password: %s\n",this->socks5_user_passwd.c_str()); 
-    printf("no proxy hosts: %s\n",this->noproxy_hosts.c_str()); 
+    printf("HTTP server name: %s\n",this->http_server_name.c_str());
+    printf("HTTP server port: %d\n",this->http_server_port);
+    printf("HTTP user name: %s\n",this->http_user_name.c_str());
+    //printf("HTTP user password: %s\n",this->http_user_passwd.c_str());
+    printf("SOCKS server name: %s\n",this->socks_server_name.c_str());
+    printf("SOCKS server port: %d\n",this->socks_server_port);
+    printf("SOCKS5 user name: %s\n",this->socks5_user_name.c_str());
+    //printf("SOCKS5 user password: %s\n",this->socks5_user_passwd.c_str());
+    printf("no proxy hosts: %s\n",this->noproxy_hosts.c_str());
 }
 
 void HOST_INFO::print() {
@@ -292,12 +298,26 @@ void HOST_INFO::print() {
         }
         if (ci.have_opencl) {
             ci.opencl_prop.peak_flops = ci.peak_flops;
-            ci.opencl_prop.opencl_available_ram = ci.opencl_prop.global_mem_size;
+            ci.opencl_prop.opencl_available_ram = (double)ci.opencl_prop.global_mem_size;
             ci.opencl_prop.is_used = COPROC_USED;
             ci.opencl_prop.description(buf, sizeof(buf), "Intel GPU");
             printf("    %s\n", buf);
         }
     }
+    COPROC_APPLE &cap = coprocs.apple_gpu;
+    if (cap.count) {
+        printf("  Apple GPU\n");
+        if (cap.count > 1) {
+            printf("    Count: %d\n", cap.count);
+        }
+        if (cap.have_opencl) {
+            cap.opencl_prop.peak_flops = cap.peak_flops;
+            cap.opencl_prop.opencl_available_ram = (double)cap.opencl_prop.global_mem_size;
+            cap.opencl_prop.is_used = COPROC_USED;
+            cap.opencl_prop.description(buf, sizeof(buf), "Apple GPU");
+            printf("    %s\n", buf);
+        }
+    }
 }
 
 void SIMPLE_GUI_INFO::print() {
@@ -426,8 +446,8 @@ void PROJECTS::print_urls() {
 void DISK_USAGE::print() {
     unsigned int i;
     printf("======== Disk usage ========\n");
-    printf("total: %.2fMB\n", d_total/MEGA);
-    printf("free: %.2fMB\n", d_free/MEGA);
+    printf("total: %.2fGB\n", d_total/GIGA);
+    printf("free: %.2fGB\n", d_free/GIGA);
     for (i=0; i<projects.size(); i++) {
         printf("%d) -----------\n", i+1);
         projects[i]->print_disk_usage();
@@ -487,8 +507,8 @@ void OLD_RESULT::print() {
         "   app name: %s\n"
         "   exit status: %d\n"
         "   elapsed time: %f sec\n"
-        "   completed time: %s\n"
-        "   reported time: %s\n",
+        "   task completed: %s\n"
+        "   acked by project: %s\n",
         result_name,
         project_url,
         app_name,
